import { Callout } from 'nextra/components'

# Example Scripts For Using The Library

<Callout type="info" emoji="ℹ️">
  Before running examples, please install extra dependencies with `pip install sotopia[examples]` or `uv run --extra examples <the example script>` if you are using uv.
</Callout>

```python
python examples/evaluate_existing_episodes.py --tag=<tag to upload to the database> --model=<the model used to re-evaluate the existing episodes> --batch_size=<batch size used for evaluation> --push-to-db
```

Run ```python examples/evaluate_existing_episodes.py --help``` for more information.

### Example 1.1: benchmarking the evaluator
```python
python examples/benchmark_evaluator.py --push-to-db --model=<the model used to be evaluated as evaluator> --tag=<tag to upload to the database> --batch_size=10
```

## Example 2: Generate script-like episodes
See `docs/simulation_modes.md` for more information.
